import os
import re
from pathlib import Path
import subprocess

def update_version():
    """Update version in pyproject.toml, README.md, and meta.yaml"""
    # Update pyproject.toml
    pyproject_path = Path("pyproject.toml")
    meta_yaml_path = Path("src/rolypoly/recipes/bbmapy/meta.yaml")
    readme_path = Path("README.md")

    if pyproject_path.exists():
        content = pyproject_path.read_text()
        # Update version in pyproject.toml
        version_match = re.search(r'version = "0.0.(\d+)"', content)
        new_version = int(version_match.group(1)) + 1
        new_version = f"0.0.{new_version}"
        content = re.sub(r'version = "[^"]+"', f'version = "{new_version}"', content)
        pyproject_path.write_text(content)
        print(f"Updated pyproject.toml version to {new_version}")

    # Update README.md
    if readme_path.exists():
        content = readme_path.read_text()
        # Update version badge or version section in README
        content = re.sub(
            r"Current BBMap version: 0.0.\d+",
            f"Current BBMap version: {new_version}",
            content,
        )
        readme_path.write_text(content)
        print(f"Updated README.md version to {new_version}")
    if meta_yaml_path.exists():
        content = meta_yaml_path.read_text()
        content = re.sub(r'version: 0.0.\d+', f'version: {new_version}', content)
        meta_yaml_path.write_text(content)
        print(f"Updated meta.yaml version to {new_version}")


def main():
    # Get package root directory
    package_root = Path(__file__).parent.parent
    print(package_root)
    vendor_dir = package_root / "bbmapy/vendor"
    os.makedirs(vendor_dir, exist_ok=True)

    # Get and update version
    update_version()
    print("Update completed successfully!")
    subprocess.run(['git', 'add', 'pyproject.toml', 'README.md'])
    subprocess.run(['git', 'add', '. '])
    subprocess.run(['git', 'commit', '-m', 'Update version'])
    subprocess.run(['git', 'push'])
    print("Pushed to git")
    


if __name__ == "__main__":
    main()
    # this scripts is for development purposes only, when creating a new release to pypi and maybe bioconda.
